normalize

Function normalize 

pub fn normalize(
    format: &AgentFileFormat,
    value: &Value,
    raw: &str,
) -> Result<AgentFile>
Convert a raw parsed value into the canonical AgentFile representation.

For CopilotAgentMd the raw source is passed so we can extract the Markdown body (everything after the closing --- frontmatter delimiter) as the system prompt.